nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Mcr

Struct Mcr 

#[repr(transparent)]
pub struct Mcr(pub u32);
Match Control Register. The MCR is used to control if an interrupt is generated and if the TC is reset when a Match occurs.

Tuple Fields

0: u32

Implementations

Source

impl Mcr

pub const fn mr0i(&self) -> bool

Interrupt on MR0: an interrupt is generated when MR0 matches the value in the TC. 0 = disabled. 1 = enabled.

pub const fn set_mr0i(&mut self, val: bool)

Interrupt on MR0: an interrupt is generated when MR0 matches the value in the TC. 0 = disabled. 1 = enabled.

pub const fn mr0r(&self) -> bool

Reset on MR0: the TC will be reset if MR0 matches it. 0 = disabled. 1 = enabled.

pub const fn set_mr0r(&mut self, val: bool)

Reset on MR0: the TC will be reset if MR0 matches it. 0 = disabled. 1 = enabled.

pub const fn mr0s(&self) -> bool

Stop on MR0: the TC and PC will be stopped and TCR[0] will be set to 0 if MR0 matches the TC. 0 = disabled. 1 = enabled.

pub const fn set_mr0s(&mut self, val: bool)

Stop on MR0: the TC and PC will be stopped and TCR[0] will be set to 0 if MR0 matches the TC. 0 = disabled. 1 = enabled.

pub const fn mr1i(&self) -> bool

Interrupt on MR1: an interrupt is generated when MR1 matches the value in the TC. 0 = disabled. 1 = enabled. 0 = disabled. 1 = enabled.

pub const fn set_mr1i(&mut self, val: bool)

Interrupt on MR1: an interrupt is generated when MR1 matches the value in the TC. 0 = disabled. 1 = enabled. 0 = disabled. 1 = enabled.

pub const fn mr1r(&self) -> bool

Reset on MR1: the TC will be reset if MR1 matches it. 0 = disabled. 1 = enabled.

pub const fn set_mr1r(&mut self, val: bool)

Reset on MR1: the TC will be reset if MR1 matches it. 0 = disabled. 1 = enabled.

pub const fn mr1s(&self) -> bool

Stop on MR1: the TC and PC will be stopped and TCR[0] will be set to 0 if MR1 matches the TC. 0 = disabled. 1 = enabled.

pub const fn set_mr1s(&mut self, val: bool)

Stop on MR1: the TC and PC will be stopped and TCR[0] will be set to 0 if MR1 matches the TC. 0 = disabled. 1 = enabled.

pub const fn mr2i(&self) -> bool

Interrupt on MR2: an interrupt is generated when MR2 matches the value in the TC. 0 = disabled. 1 = enabled.

pub const fn set_mr2i(&mut self, val: bool)

Interrupt on MR2: an interrupt is generated when MR2 matches the value in the TC. 0 = disabled. 1 = enabled.

pub const fn mr2r(&self) -> bool

Reset on MR2: the TC will be reset if MR2 matches it. 0 = disabled. 1 = enabled.

pub const fn set_mr2r(&mut self, val: bool)

Reset on MR2: the TC will be reset if MR2 matches it. 0 = disabled. 1 = enabled.

pub const fn mr2s(&self) -> bool

Stop on MR2: the TC and PC will be stopped and TCR[0] will be set to 0 if MR2 matches the TC. 0 = disabled. 1 = enabled.

pub const fn set_mr2s(&mut self, val: bool)

Stop on MR2: the TC and PC will be stopped and TCR[0] will be set to 0 if MR2 matches the TC. 0 = disabled. 1 = enabled.

pub const fn mr3i(&self) -> bool

Interrupt on MR3: an interrupt is generated when MR3 matches the value in the TC. 0 = disabled. 1 = enabled.

pub const fn set_mr3i(&mut self, val: bool)

Interrupt on MR3: an interrupt is generated when MR3 matches the value in the TC. 0 = disabled. 1 = enabled.

pub const fn mr3r(&self) -> bool

Reset on MR3: the TC will be reset if MR3 matches it. 0 = disabled. 1 = enabled.

pub const fn set_mr3r(&mut self, val: bool)

Reset on MR3: the TC will be reset if MR3 matches it. 0 = disabled. 1 = enabled.

pub const fn mr3s(&self) -> bool

Stop on MR3: the TC and PC will be stopped and TCR[0] will be set to 0 if MR3 matches the TC. 0 = disabled. 1 = enabled.

pub const fn set_mr3s(&mut self, val: bool)

Stop on MR3: the TC and PC will be stopped and TCR[0] will be set to 0 if MR3 matches the TC. 0 = disabled. 1 = enabled.

pub const fn mr0rl(&self) -> bool

Reload MR0 with the contents of the Match 0 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.

pub const fn set_mr0rl(&mut self, val: bool)

Reload MR0 with the contents of the Match 0 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.

pub const fn mr1rl(&self) -> bool

Reload MR1 with the contents of the Match 1 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.

pub const fn set_mr1rl(&mut self, val: bool)

Reload MR1 with the contents of the Match 1 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.

pub const fn mr2rl(&self) -> bool

Reload MR2 with the contents of the Match 2 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.

pub const fn set_mr2rl(&mut self, val: bool)

Reload MR2 with the contents of the Match 2 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.

pub const fn mr3rl(&self) -> bool

Reload MR3 with the contents of the Match 3 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.

pub const fn set_mr3rl(&mut self, val: bool)

Reload MR3 with the contents of the Match 3 Shadow Register when the TC is reset to zero (either via a match event or a write to bit 1 of the TCR). 0 = disabled. 1 = enabled.