#[repr(transparent)]pub struct Pc(pub u32);Expand description
Prescale Counter. The 32 bit PC is a counter which is incremented to the value stored in PR. When the value in PR is reached, the TC is incremented and the PC is cleared. The PC is observable and controllable through the bus interface.
Tuple Fields
0: u32Implementations