#[repr(transparent)]pub struct Tcr(pub u32);Expand description
Timer Control Register. The TCR is used to control the Timer Counter functions. The Timer Counter can be disabled or reset through the TCR.
Tuple Fields
0: u32Implementations