#[repr(transparent)]pub struct Ccr(pub u32);Expand description
Capture Control Register. The CCR controls which edges of the capture inputs are used to load the Capture Registers and whether or not an interrupt is generated when a capture takes place.
Tuple Fields
0: u32Implementations
Sourceimpl Ccr
impl Ccr
Sourcepub const fn cap0re(&self) -> bool
pub const fn cap0re(&self) -> bool
Rising edge of capture channel 0: a sequence of 0 then 1 causes CR0 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap0re(&mut self, val: bool)
pub const fn set_cap0re(&mut self, val: bool)
Rising edge of capture channel 0: a sequence of 0 then 1 causes CR0 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn cap0fe(&self) -> bool
pub const fn cap0fe(&self) -> bool
Falling edge of capture channel 0: a sequence of 1 then 0 causes CR0 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap0fe(&mut self, val: bool)
pub const fn set_cap0fe(&mut self, val: bool)
Falling edge of capture channel 0: a sequence of 1 then 0 causes CR0 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn cap0i(&self) -> bool
pub const fn cap0i(&self) -> bool
Generate interrupt on channel 0 capture event: a CR0 load generates an interrupt.
Sourcepub const fn set_cap0i(&mut self, val: bool)
pub const fn set_cap0i(&mut self, val: bool)
Generate interrupt on channel 0 capture event: a CR0 load generates an interrupt.
Sourcepub const fn cap1re(&self) -> bool
pub const fn cap1re(&self) -> bool
Rising edge of capture channel 1: a sequence of 0 then 1 causes CR1 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap1re(&mut self, val: bool)
pub const fn set_cap1re(&mut self, val: bool)
Rising edge of capture channel 1: a sequence of 0 then 1 causes CR1 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn cap1fe(&self) -> bool
pub const fn cap1fe(&self) -> bool
Falling edge of capture channel 1: a sequence of 1 then 0 causes CR1 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap1fe(&mut self, val: bool)
pub const fn set_cap1fe(&mut self, val: bool)
Falling edge of capture channel 1: a sequence of 1 then 0 causes CR1 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn cap1i(&self) -> bool
pub const fn cap1i(&self) -> bool
Generate interrupt on channel 1 capture event: a CR1 load generates an interrupt.
Sourcepub const fn set_cap1i(&mut self, val: bool)
pub const fn set_cap1i(&mut self, val: bool)
Generate interrupt on channel 1 capture event: a CR1 load generates an interrupt.
Sourcepub const fn cap2re(&self) -> bool
pub const fn cap2re(&self) -> bool
Rising edge of capture channel 2: a sequence of 0 then 1 causes CR2 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap2re(&mut self, val: bool)
pub const fn set_cap2re(&mut self, val: bool)
Rising edge of capture channel 2: a sequence of 0 then 1 causes CR2 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn cap2fe(&self) -> bool
pub const fn cap2fe(&self) -> bool
Falling edge of capture channel 2: a sequence of 1 then 0 causes CR2 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap2fe(&mut self, val: bool)
pub const fn set_cap2fe(&mut self, val: bool)
Falling edge of capture channel 2: a sequence of 1 then 0 causes CR2 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn cap2i(&self) -> bool
pub const fn cap2i(&self) -> bool
Generate interrupt on channel 2 capture event: a CR2 load generates an interrupt.
Sourcepub const fn set_cap2i(&mut self, val: bool)
pub const fn set_cap2i(&mut self, val: bool)
Generate interrupt on channel 2 capture event: a CR2 load generates an interrupt.
Sourcepub const fn cap3re(&self) -> bool
pub const fn cap3re(&self) -> bool
Rising edge of capture channel 3: a sequence of 0 then 1 causes CR3 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap3re(&mut self, val: bool)
pub const fn set_cap3re(&mut self, val: bool)
Rising edge of capture channel 3: a sequence of 0 then 1 causes CR3 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn cap3fe(&self) -> bool
pub const fn cap3fe(&self) -> bool
Falling edge of capture channel 3: a sequence of 1 then 0 causes CR3 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.
Sourcepub const fn set_cap3fe(&mut self, val: bool)
pub const fn set_cap3fe(&mut self, val: bool)
Falling edge of capture channel 3: a sequence of 1 then 0 causes CR3 to be loaded with the contents of TC. 0 = disabled. 1 = enabled.